OppositeGroupPoint

Enum OppositeGroupPoint 

#[repr(u8)]
pub enum OppositeGroupPoint {
Show 24 variants PosOnePosTwoNegThree = 1, PosOneNegTwoPosThree = 2, NegOnePosTwoPosThree = 4, NegOneNegTwoNegThree = 7, PosThreePosTwoPosOne = 8, PosThreeNegTwoNegOne = 11, NegThreePosTwoNegOne = 13, NegThreeNegTwoPosOne = 14, PosOnePosThreePosTwo = 16, PosOneNegThreeNegTwo = 19, NegOnePosThreeNegTwo = 21, NegOneNegThreePosTwo = 22, PosThreePosOneNegTwo = 25, PosThreeNegOnePosTwo = 26, NegThreePosOnePosTwo = 28, NegThreeNegOneNegTwo = 31, PosTwoPosOnePosThree = 32, PosTwoNegOneNegThree = 35, NegTwoPosOneNegThree = 37, NegTwoNegOnePosThree = 38, PosTwoPosThreeNegOne = 41, PosTwoNegThreePosOne = 42, NegTwoPosThreePosOne = 44, NegTwoNegThreeNegOne = 47,
}
The set of CubeSurfacePoints that can be made to coincide with the Reference Point using just one improper rotation.

Not coincidentally, their binary representations all have an odd number of ones.

Variants



PosOnePosTwoNegThree = 1

The point [1, 2, -3]. Divided by the Reference Point, it yields a reflection through the z = 0 plane. Its arithmetic representation is equal to 20, thus it is the zeroth Elementary Reflection.



PosOneNegTwoPosThree = 2

The point [1, -2, 3]. Divided by the Reference Point, it yields a reflection through the y = 0 plane. Its arithmetic representation is equal to 21, thus it is the first Elementary Reflection.



NegOnePosTwoPosThree = 4

The point [-1, 2, 3]. Divided by the Reference Point, it yields a reflection through the x = 0 plane. Its arithmetic representation is equal to 22, thus it is the second Elementary Reflection.



NegOneNegTwoNegThree = 7

The point [-1, -2, -3]. Divided by the Reference Point, it yields a complete central inversion, ie a negation of all coördinates.



PosThreePosTwoPosOne = 8

The point [3, 2, 1]. Divided by the Reference Point, it yields a reflection through the x = z plane. Its arithmetic representation is equal to 23, thus it is the third Elementary Reflection.



PosThreeNegTwoNegOne = 11

The point [3, -2, -1]. Divided by the Reference Point, it yields a rotoreflection of 90° with respect to the y axis.



NegThreePosTwoNegOne = 13

The point [-3, 2, -1]. Divided by the Reference Point, it yields a reflection through the z = -x plane.



NegThreeNegTwoPosOne = 14

The point [-3, -2, 1]. Divided by the Reference Point, it yields a rotoreflection of -90° with respect to the y axis.



PosOnePosThreePosTwo = 16

The point [1, 3, 2]. Divided by the Reference Point, it yields a reflection through the z = y plane. Its arithmetic representation is equal to 24, thus it is the fourth Elementary Reflection.



PosOneNegThreeNegTwo = 19

The point [1, -3, -2]. Divided by the Reference Point, it yields a reflection through the y = -z plane.



NegOnePosThreeNegTwo = 21

The point [-1, 3, -2]. Divided by the Reference Point, it yields a rotoreflection of -90° with respect to the x = y = z axis.



NegOneNegThreePosTwo = 22

The point [-1, -3, 2]. Divided by the Reference Point, it yields a rotoreflection of 90° with respect to the x axis.



PosThreePosOneNegTwo = 25

The point [3, 1, -2]. Divided by the Reference Point, it yields a rotoreflection of -60° with respect to the x = -y = -z axis.



PosThreeNegOnePosTwo = 26

The point [3, -1, 2]. Divided by the Reference Point, it yields a rotoreflection of 60° with respect to the x = y = -z axis.



NegThreePosOnePosTwo = 28

The point [-3, 1, 2]. Divided by the Reference Point, it yields a rotoreflection of 60° with respect to the x = -y = z axis.



NegThreeNegOneNegTwo = 31

The point [-3, -1, -2]. Divided by the Reference Point, it yields a rotoreflection of -60° with respect to the x = y = z axis.



PosTwoPosOnePosThree = 32

The point [2, 1, 3]. Divided by the Reference Point, it yields a reflection through the y = x plane. Its arithmetic representation is equal to 25, thus it is the fifth and final Elementary Reflection.



PosTwoNegOneNegThree = 35

The point [2, -1, -3]. Divided by the Reference Point, it yields a reflection through the x = -y plane.



NegTwoPosOneNegThree = 37

The point [-2, 1, -3]. Divided by the Reference Point, it yields a rotoreflection of 90° with respect to the z axis.



NegTwoNegOnePosThree = 38

The point [-2, -1, 3]. Divided by the Reference Point, it yields a rotoreflection of -90° with respect to the z axis.



PosTwoPosThreeNegOne = 41

The point [2, 3, -1]. Divided by the Reference Point, it yields a rotoreflection of -60° with respect to the x = -y = z axis.



PosTwoNegThreePosOne = 42

The point [2, -3, 1]. Divided by the Reference Point, it yields a rotoreflection of 60° with respect to the x = -y = -z axis.



NegTwoPosThreePosOne = 44

The point [-2, 3, 1]. Divided by the Reference Point, it yields a rotoreflection of -60° with respect to the x = y = -z axis.



NegTwoNegThreeNegOne = 47

The point [-2, -3, -1]. Divided by the Reference Point, it yields a rotoreflection of 60° with respect to the x = y = z axis.

Implementations

Source

impl OppositeGroupPoint

pub const fn downcast(self) -> CubeSurfacePoint

Down-casts one OppositeGroupPoint to a CubeSurfacePoint.

pub const fn beside(self) -> ReferenceGroupPoint

pub const fn opposite(self) -> ReferenceGroupPoint

pub const fn opposite_then_beside(self) -> Self

pub const fn one_right_angle_cw(self) -> Self

pub const fn one_right_angle_acw(self) -> Self

pub const fn flip_sign_of_2(self) -> ReferenceGroupPoint

pub const fn flip_2_and_3(self) -> Self

pub const fn n_right_angles_cw(self, angle: u8) -> Self

pub const fn n_right_angles_acw(self, angle: u8) -> Self

pub const fn mul_prop(self, other: ProperRotation) -> OppositeGroupPoint

Multiplies one OppositeGroupPoint with one ProperRotation, producing one OppositeGroupPoint as a result. Useful for static confirmation of Geometric Groups.

pub const fn mul_improp(self, other: ImproperRotation) -> ReferenceGroupPoint

Multiplies one OppositeGroupPoint with one ImproperRotation, producing one ReferenceGroupPoint as a result. Useful for static confirmation of Geometric Groups.

pub const fn div_prop(self, other: OppositeGroupPoint) -> ProperRotation

Divides one OppositeGroupPoint by one OppositeGroupPoint, producing one ProperRotation as a result. Useful for static confirmation of Geometric Group.

pub const fn div_improp(self, other: ReferenceGroupPoint) -> ImproperRotation

Divides one OppositeGroupPoint by one ReferenceGroupPoint, producing one ImproperRotation as a result. Useful for static confirmation of Geometric Group.

pub const fn direction(self) -> Direction