#[repr(u8)]pub enum ReferenceGroupPoint {
Show 24 variants
PosOnePosTwoPosThree = 0,
PosOneNegTwoNegThree = 3,
NegOnePosTwoNegThree = 5,
NegOneNegTwoPosThree = 6,
PosThreePosTwoNegOne = 9,
PosThreeNegTwoPosOne = 10,
NegThreePosTwoPosOne = 12,
NegThreeNegTwoNegOne = 15,
PosOnePosThreeNegTwo = 17,
PosOneNegThreePosTwo = 18,
NegOnePosThreePosTwo = 20,
NegOneNegThreeNegTwo = 23,
PosThreePosOnePosTwo = 24,
PosThreeNegOneNegTwo = 27,
NegThreePosOneNegTwo = 29,
NegThreeNegOnePosTwo = 30,
PosTwoPosOneNegThree = 33,
PosTwoNegOnePosThree = 34,
NegTwoPosOnePosThree = 36,
NegTwoNegOneNegThree = 39,
PosTwoPosThreePosOne = 40,
PosTwoNegThreeNegOne = 43,
NegTwoPosThreeNegOne = 45,
NegTwoNegThreePosOne = 46,
}Expand description
The set of CubeSurfacePoints that can be made to coincide with the
Reference Point using just one proper rotation.
Not coincidentally, their binary representations all have an even number of ones.
Variants
PosOnePosTwoPosThree = 0
The point [1, 2, 3]. Also the Point of Reference. Divided by itself,
it yields –unsurprisingly enough– the identity operation.
PosOneNegTwoNegThree = 3
The point [1, -2, -3]. Divided by the Reference Point, it yields a
rotation of 180° around the x axis.
NegOnePosTwoNegThree = 5
The point [-1, 2, -3]. Divided by the Reference Point, it yields a
rotation of 180° around the y axis.
NegOneNegTwoPosThree = 6
The point [-1, -2, 3]. Divided by the Reference Point, it yields a
rotation of 180° around the z axis.
PosThreePosTwoNegOne = 9
The point [3, 2, -1]. Divided by the Reference Point, it yields a
rotation of 90° around the y axis.
PosThreeNegTwoPosOne = 10
The point [3, -2, 1]. Divided by the Reference Point, it yields a
rotation of 180° around the y = 0, z = x axis.
NegThreePosTwoPosOne = 12
The point [-3, 2, 1]. Divided by the Reference Point, it yields a
rotation of -90° around the y axis.
NegThreeNegTwoNegOne = 15
The point [-3, -2, -1]. Divided by the Reference Point, it yields a
rotation of 180° around the y = 0, z = -x axis.
PosOnePosThreeNegTwo = 17
The point [1, 3, -2]. Divided by the Reference Point, it yields a
rotation of -90° around the x axis.
PosOneNegThreePosTwo = 18
The point [1, -3, 2]. Divided by the Reference Point, it yields a
rotation of 90° around the x axis.
NegOnePosThreePosTwo = 20
The point [-1, 3, 2]. Divided by the Reference Point, it yields a
rotation of 180° around the x = 0, y = z axis.
NegOneNegThreeNegTwo = 23
The point [-1, -3, -2]. Divided by the Reference Point, it yields a
rotation of 180° around the x = 0, y = -z axis.
PosThreePosOnePosTwo = 24
The point [3, 1, 2]. Divided by the Reference Point, it yields a
rotation of 120° around the x = y = z axis.
PosThreeNegOneNegTwo = 27
The point [3, -1, -2]. Divided by the Reference Point, it yields a
rotation of -120° around the x = -y = z axis.
NegThreePosOneNegTwo = 29
The point [-3, 1, -2]. Divided by the Reference Point, it yields a
rotation of -120° around the x = y = -z axis.
NegThreeNegOnePosTwo = 30
The point [-3, -1, 2]. Divided by the Reference Point, it yields a
rotation of 120° around the x = -y = -z axis.
PosTwoPosOneNegThree = 33
The point [2, 1, -3]. Divided by the Reference Point, it yields a
rotation of 180° around the z = 0, x = y axis.
PosTwoNegOnePosThree = 34
The point [2, -1, 3]. Divided by the Reference Point, it yields a
rotation of -90° around the z axis.
NegTwoPosOnePosThree = 36
The point [-2, 1, 3]. Divided by the Reference Point, it yields a
rotation of 90° around the z axis.
NegTwoNegOneNegThree = 39
The point [-2, -1, -3]. Divided by the Reference Point, it yields a
rotation of 180° around the z = 0, x = -y axis.
PosTwoPosThreePosOne = 40
The point [2, 3, 1]. Divided by the Reference Point, it yields a
rotation of -120° around the x = y = z axis.
PosTwoNegThreeNegOne = 43
The point [2, -3, -1]. Divided by the Reference Point, it yields a
rotation of 120° around the x = y = -z axis.
NegTwoPosThreeNegOne = 45
The point [-2, 3, -1]. Divided by the Reference Point, it yields a
rotation of -120° around the x = -y = -z axis.
NegTwoNegThreePosOne = 46
The point [-2, -3, 1]. Divided by the Reference Point, it yields a
rotation of 120° around the x = -y = z axis.
Implementations
Sourceimpl ReferenceGroupPoint
impl ReferenceGroupPoint
Sourcepub const fn downcast(self) -> CubeSurfacePoint
pub const fn downcast(self) -> CubeSurfacePoint
Down-casts one ReferenceGroupPoint to a CubeSurfacePoint.
Sourcepub const fn beside(self) -> OppositeGroupPoint
pub const fn beside(self) -> OppositeGroupPoint
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn opposite(self) -> OppositeGroupPoint
pub const fn opposite(self) -> OppositeGroupPoint
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn opposite_then_beside(self) -> Self
pub const fn opposite_then_beside(self) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn one_right_angle_cw(self) -> Self
pub const fn one_right_angle_cw(self) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn one_right_angle_acw(self) -> Self
pub const fn one_right_angle_acw(self) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn flip_sign_of_2(self) -> OppositeGroupPoint
pub const fn flip_sign_of_2(self) -> OppositeGroupPoint
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn flip_2_and_3(self) -> Self
pub const fn flip_2_and_3(self) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn n_right_angles_cw(self, angle: u8) -> Self
pub const fn n_right_angles_cw(self, angle: u8) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn n_right_angles_acw(self, angle: u8) -> Self
pub const fn n_right_angles_acw(self, angle: u8) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn mul_prop(self, other: ProperRotation) -> ReferenceGroupPoint
pub const fn mul_prop(self, other: ProperRotation) -> ReferenceGroupPoint
Multiplies one ReferenceGroupPoint with one ProperRotation, producing one ReferenceGroupPoint as a result.
Useful for static confirmation of Geometric Groups.
Sourcepub const fn mul_improp(self, other: ImproperRotation) -> OppositeGroupPoint
pub const fn mul_improp(self, other: ImproperRotation) -> OppositeGroupPoint
Multiplies one ReferenceGroupPoint with one ImproperRotation, producing one OppositeGroupPoint as a result.
Useful for static confirmation of Geometric Groups.
Sourcepub const fn div_prop(self, other: ReferenceGroupPoint) -> ProperRotation
pub const fn div_prop(self, other: ReferenceGroupPoint) -> ProperRotation
Divides one ReferenceGroupPoint by one ReferenceGroupPoint, producing one ProperRotation as a result.
Useful for static confirmation of Geometric Group.
Sourcepub const fn div_improp(self, other: OppositeGroupPoint) -> ImproperRotation
pub const fn div_improp(self, other: OppositeGroupPoint) -> ImproperRotation
Divides one ReferenceGroupPoint by one OppositeGroupPoint, producing one ImproperRotation as a result.
Useful for static confirmation of Geometric Group.
Sourcepub const fn direction(self) -> Direction
pub const fn direction(self) -> Direction
Please refer to
the function of the same name
in CubeSurfacePoint.