CubeSurfacePoint

Struct CubeSurfacePoint 

pub struct CubeSurfacePoint<const BIG_LUTS: bool>(pub CubeSurfacePoint);
A helper wrapper-type around a CubeSurfacePoint that operates using look-up tables.

A luts::CubeSurfacePoint::<false> only has LUTs 48 bytes long, but might need more than one look-up for each operation. A luts::CubeSurfacePoint::<true>, in contrast, has LUTs up to 2304 bytes long, but only ever needs one look-up per operation.

Tuple Fields

0: CubeSurfacePoint

Implementations

Source

impl<const BIG_LUTS: bool> CubeSurfacePoint<BIG_LUTS>

pub const REFERENCE_POINT: Self

Please refer to the ordinary REFERENCE_POINT.

pub const fn direction(self) -> Direction

Source

impl CubeSurfacePoint<false>

pub const fn one_right_angle_cw(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn one_right_angle_acw(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn beside(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn opposite(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn opposite_then_beside(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn flip_sign_of_2(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn flip_2_and_3(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn n_right_angles<const CLOCKWISE: bool>(self, angle: u8) -> Self

pub const fn n_right_angles_acw(self, angle: u8) -> Self

pub const fn n_right_angles_cw(self, angle: u8) -> Self

Source

impl CubeSurfacePoint<true>

pub const fn one_right_angle_cw(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn one_right_angle_acw(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn beside(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn opposite(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn opposite_then_beside(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn flip_sign_of_2(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn flip_2_and_3(self) -> Self

Please refer to the function of the same name in the basic CubeSurfacePoint.

pub const fn n_right_angles_cw(self, angle: u8) -> Self

pub const fn n_right_angles_acw(self, angle: u8) -> Self

pub fn div_alt(self, divisor: Self) -> Rotation

An alternative implementation of division, that uses the same big LUT as multiplication does, but performs two look-ups instead of one.