ReferenceGroupPoint

Struct ReferenceGroupPoint 

pub struct ReferenceGroupPoint(pub ReferenceGroupPoint);
As per the basic ReferenceGroupPoint. Each LUT used is up to 576 bytes in length, and each operation is guaranteed to consist of a single look-up.

Tuple Fields

0: ReferenceGroupPoint

Implementations

Source

impl ReferenceGroupPoint

pub const fn direction(self) -> Direction

pub const fn beside(self) -> OppositeGroupPoint

pub const fn opposite(self) -> OppositeGroupPoint

pub const fn flip_sign_of_2(self) -> OppositeGroupPoint

pub const fn opposite_then_beside(self) -> ReferenceGroupPoint

pub const fn flip_2_and_3(self) -> ReferenceGroupPoint

pub const fn one_right_angle_cw(self) -> ReferenceGroupPoint

pub const fn one_right_angle_acw(self) -> ReferenceGroupPoint

pub const fn n_right_angles_cw(self, angle: u8) -> Self

pub const fn n_right_angles_acw(self, angle: u8) -> Self

pub const fn div_prop(self, other: ReferenceGroupPoint) -> ProperRotation

Please refer to the function of the same name in the basic ReferenceGroupPoint.

pub const fn div_improp(self, other: OppositeGroupPoint) -> ImproperRotation

Please refer to the function of the same name in the basic ReferenceGroupPoint.

pub const fn mul_prop(self, other: ProperRotation) -> ReferenceGroupPoint

Please refer to the function of the same name in the basic ReferenceGroupPoint.

pub const fn mul_improp(self, other: ImproperRotation) -> OppositeGroupPoint

Please refer to the function of the same name in the basic ReferenceGroupPoint.

pub fn div_alt(self, x: Self) -> ProperRotation

An alternative implementation of division, that uses the same big LUT as multiplication does, but performs two look-ups instead of one.