Rotation

Struct Rotation 

pub struct Rotation { /* private fields */ }
A data-type that describes, within 6 bits, the transformation from one CubeSurfacePoint to another.

Usage

let rotation = ending_point / beginning_point;
assert_eq!(beginning_point * rotation, ending_point);

Representation

For a complete correspondence between arithmetic values and geometric transformations, please refer to the documentation for CubeSurfacePoint. In here, we will describe the correspondence of each transformation with its binary representation.

The gist is that the three first bits describe the order in which the three coördinates must be positioned, while the last three bits describe which of their signs have to be flipped. It must be noted that the bits cannot be examined in arbitrary order: Bit 3 must always be examined first, and the three last bits must be examined last. Their order and meaning is as follows:

  • 3: Swaps coöordinates 1 and 3.
  • 4: Swaps coöordinates 2 and 3.
  • 5: Swaps coöordinates 1 and 2.
  • 2: Flips the sign of coördinate 1.
  • 1: Flips the sign of coördinate 2.
  • 0: Flips the sign of coördinate 3.

Also note that this data-type encodes both proper and improper rotations. The ProperRotation and ImproperRotation data-types separate the two.

Multiplying/dividing rotations together

The various rotation data-types can be multiplied, and therefore have had Mul and Div implemented between them:

  • The ordinary Rotation can only be multiplied with itself.
  • In contrast, the ProperRotation and the ImproperRotation can be multiplied both with themselves and with each other.

Implementations

Source

impl Rotation

pub const fn mul(self, x: CubeSurfacePoint) -> CubeSurfacePoint

Because Mul is not const.