pub struct CubeSurfacePoint<const BIG_LUTS: bool>(pub CubeSurfacePoint);Expand description
A helper wrapper-type around a CubeSurfacePoint that operates using
look-up tables.
A luts::CubeSurfacePoint::<false> only has LUTs 48
bytes long, but might need more than one look-up for each operation. A
luts::CubeSurfacePoint::<true>, in contrast, has LUTs up to 2304 bytes
long, but only ever needs one look-up per operation.
Tuple Fields
0: CubeSurfacePointImplementations
Sourceimpl<const BIG_LUTS: bool> CubeSurfacePoint<BIG_LUTS>
impl<const BIG_LUTS: bool> CubeSurfacePoint<BIG_LUTS>
Sourcepub const REFERENCE_POINT: Self
pub const REFERENCE_POINT: Self
Please refer to the ordinary
REFERENCE_POINT.
Sourcepub const fn direction(self) -> Direction
pub const fn direction(self) -> Direction
Please refer to the function of the same name in CubeSurfacePoint.
Sourceimpl CubeSurfacePoint<false>
impl CubeSurfacePoint<false>
Sourcepub const fn one_right_angle_cw(self) -> Self
pub const fn one_right_angle_cw(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn one_right_angle_acw(self) -> Self
pub const fn one_right_angle_acw(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn beside(self) -> Self
pub const fn beside(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn opposite(self) -> Self
pub const fn opposite(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn opposite_then_beside(self) -> Self
pub const fn opposite_then_beside(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn flip_sign_of_2(self) -> Self
pub const fn flip_sign_of_2(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn flip_2_and_3(self) -> Self
pub const fn flip_2_and_3(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn n_right_angles<const CLOCKWISE: bool>(self, angle: u8) -> Self
pub const fn n_right_angles<const CLOCKWISE: bool>(self, angle: u8) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn n_right_angles_acw(self, angle: u8) -> Self
pub const fn n_right_angles_acw(self, angle: u8) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn n_right_angles_cw(self, angle: u8) -> Self
pub const fn n_right_angles_cw(self, angle: u8) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.
Sourceimpl CubeSurfacePoint<true>
impl CubeSurfacePoint<true>
Sourcepub const fn one_right_angle_cw(self) -> Self
pub const fn one_right_angle_cw(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn one_right_angle_acw(self) -> Self
pub const fn one_right_angle_acw(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn beside(self) -> Self
pub const fn beside(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn opposite(self) -> Self
pub const fn opposite(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn opposite_then_beside(self) -> Self
pub const fn opposite_then_beside(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn flip_sign_of_2(self) -> Self
pub const fn flip_sign_of_2(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn flip_2_and_3(self) -> Self
pub const fn flip_2_and_3(self) -> Self
Please refer to the function of the same name in the basic CubeSurfacePoint.
Sourcepub const fn n_right_angles_cw(self, angle: u8) -> Self
pub const fn n_right_angles_cw(self, angle: u8) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.
Sourcepub const fn n_right_angles_acw(self, angle: u8) -> Self
pub const fn n_right_angles_acw(self, angle: u8) -> Self
Please refer to the function of the same name
in CubeSurfacePoint.